@@ -1,7 +1,7 @@
 /*
  * libosinfo: OS installation script
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,9 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <glib-object.h>
@@ -27,62 +24,36 @@
 #include <osinfo/osinfo_avatar_format.h>
 
 #ifndef __OSINFO_INSTALL_SCRIPT_H__
-#define __OSINFO_INSTALL_SCRIPT_H__
+# define __OSINFO_INSTALL_SCRIPT_H__
 
-/*
- * Type macros.
- */
-#define OSINFO_TYPE_INSTALL_SCRIPT                  (osinfo_install_script_get_type ())
-#define OSINFO_INSTALL_SCRIPT(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), OSINFO_TYPE_INSTALL_SCRIPT, OsinfoInstallScript))
-#define OSINFO_IS_INSTALL_SCRIPT(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OSINFO_TYPE_INSTALL_SCRIPT))
-#define OSINFO_INSTALL_SCRIPT_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), OSINFO_TYPE_INSTALL_SCRIPT, OsinfoInstallScriptClass))
-#define OSINFO_IS_INSTALL_SCRIPT_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), OSINFO_TYPE_INSTALL_SCRIPT))
-#define OSINFO_INSTALL_SCRIPT_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), OSINFO_TYPE_INSTALL_SCRIPT, OsinfoInstallScriptClass))
+# define OSINFO_TYPE_INSTALL_SCRIPT (osinfo_install_script_get_type ())
+OSINFO_DECLARE_TYPE_WITH_PRIVATE_AND_CLASS(OsinfoInstallScript,
+                                           osinfo_install_script,
+                                           OSINFO,
+                                           INSTALL_SCRIPT,
+                                           OsinfoEntity)
 
 typedef struct _OsinfoOs        OsinfoOs;
 typedef struct _OsinfoMedia     OsinfoMedia;
 typedef struct _OsinfoTree      OsinfoTree;
-typedef struct _OsinfoInstallScript        OsinfoInstallScript;
-typedef struct _OsinfoInstallScriptClass   OsinfoInstallScriptClass;
-typedef struct _OsinfoInstallScriptPrivate OsinfoInstallScriptPrivate;
 
-#define OSINFO_INSTALL_SCRIPT_PROFILE_JEOS    "jeos"
-#define OSINFO_INSTALL_SCRIPT_PROFILE_DESKTOP "desktop"
+# define OSINFO_INSTALL_SCRIPT_PROFILE_JEOS    "jeos"
+# define OSINFO_INSTALL_SCRIPT_PROFILE_DESKTOP "desktop"
 
-#define OSINFO_INSTALL_SCRIPT_PROP_TEMPLATE_URI       "template-uri"
-#define OSINFO_INSTALL_SCRIPT_PROP_TEMPLATE_DATA      "template-data"
-#define OSINFO_INSTALL_SCRIPT_PROP_PROFILE            "profile"
-#define OSINFO_INSTALL_SCRIPT_PROP_PRODUCT_KEY_FORMAT "product-key-format"
-#define OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME  "expected-filename"
-#define OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT        "path-format"
-#define OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS "can-pre-install-drivers"
-#define OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS "can-post-install-drivers"
-#define OSINFO_INSTALL_SCRIPT_PROP_NEEDS_INTERNET     "needs-internet"
-#define OSINFO_INSTALL_SCRIPT_PROP_PRE_INSTALL_DRIVERS_SIGNING_REQ "pre-install-drivers-signing-req"
-#define OSINFO_INSTALL_SCRIPT_PROP_POST_INSTALL_DRIVERS_SIGNING_REQ "post-install-drivers-signing-req"
-#define OSINFO_INSTALL_SCRIPT_PROP_INJECTION_METHOD "injection-method"
-#define OSINFO_INSTALL_SCRIPT_PROP_PREFERRED_INJECTION_METHOD "preferred-injection-method"
-#define OSINFO_INSTALL_SCRIPT_PROP_INSTALLATION_SOURCE "installation-source"
-
-/* object */
-struct _OsinfoInstallScript
-{
-    OsinfoEntity parent_instance;
-
-    /* public */
-
-    /* private */
-    OsinfoInstallScriptPrivate *priv;
-};
-
-/* class */
-struct _OsinfoInstallScriptClass
-{
-    /*< private >*/
-    OsinfoEntityClass parent_class;
-
-    /* class members */
-};
+# define OSINFO_INSTALL_SCRIPT_PROP_TEMPLATE_URI       "template-uri"
+# define OSINFO_INSTALL_SCRIPT_PROP_TEMPLATE_DATA      "template-data"
+# define OSINFO_INSTALL_SCRIPT_PROP_PROFILE            "profile"
+# define OSINFO_INSTALL_SCRIPT_PROP_PRODUCT_KEY_FORMAT "product-key-format"
+# define OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME  "expected-filename"
+# define OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT        "path-format"
+# define OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS "can-pre-install-drivers"
+# define OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS "can-post-install-drivers"
+# define OSINFO_INSTALL_SCRIPT_PROP_NEEDS_INTERNET     "needs-internet"
+# define OSINFO_INSTALL_SCRIPT_PROP_PRE_INSTALL_DRIVERS_SIGNING_REQ "pre-install-drivers-signing-req"
+# define OSINFO_INSTALL_SCRIPT_PROP_POST_INSTALL_DRIVERS_SIGNING_REQ "post-install-drivers-signing-req"
+# define OSINFO_INSTALL_SCRIPT_PROP_INJECTION_METHOD "injection-method"
+# define OSINFO_INSTALL_SCRIPT_PROP_PREFERRED_INJECTION_METHOD "preferred-injection-method"
+# define OSINFO_INSTALL_SCRIPT_PROP_INSTALLATION_SOURCE "installation-source"
 
 /**
  * OsinfoPathFormat:
@@ -96,7 +67,6 @@ typedef enum {
 
 /**
  * OsinfoDeviceDriverSigningReq:
- * Since: 0.2.6
  * @OSINFO_DEVICE_DRIVER_SIGNING_REQ_NONE: Script do not require device drivers
  * to be signed.
  * @OSINFO_DEVICE_DRIVER_SIGNING_REQ_STRICT: Script must only be given signed
@@ -110,6 +80,8 @@ typedef enum {
  * input (and thus breaking unattended installation). See
  * #OSINFO_DEVICE_DRIVER_SIGNING_REQ_STRICT on how this warning can be disabled
  * for some scripts.
+ *
+ * Since: 0.2.6
  */
 typedef enum {
     OSINFO_DEVICE_DRIVER_SIGNING_REQ_NONE,
@@ -119,7 +91,6 @@ typedef enum {
 
 /**
  * OsinfoInstallScriptInjectionMethod:
- * Since: 0.2.10
  * @OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_CDROM: Support injection of the
  * installation script trough a CD-ROM.
  * @OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_DISK: Support injection of the
@@ -130,6 +101,8 @@ typedef enum {
  * installation script trough the initrd.
  * @OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_WEB: Support injection of the
  * installation script from the web.
+ *
+ * Since: 0.2.10
  */
 typedef enum {
     OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_CDROM  = 1 << 0,
@@ -141,19 +114,18 @@ typedef enum {
 
 /**
  * OsinfoInstallScriptInstallationSource:
- * Since: 1.3.0
  * @OSINFO_INSTALL_SCRIPT_INSTALLATION_SOURCE_MEDIA: A media will be used as
  * the installation source.
  * @OSINFO_INSTALL_SCRIPT_INSTALLATION_SOURCE_NETWORK: A network method will
  * be used as installation source.
+ *
+ * Since: 1.3.0
  */
 typedef enum {
     OSINFO_INSTALL_SCRIPT_INSTALLATION_SOURCE_MEDIA,
     OSINFO_INSTALL_SCRIPT_INSTALLATION_SOURCE_NETWORK
 } OsinfoInstallScriptInstallationSource;
 
-GType osinfo_install_script_get_type(void);
-
 OsinfoInstallScript *osinfo_install_script_new(const gchar *id);
 OsinfoInstallScript *osinfo_install_script_new_uri(const gchar *id,
                                                    const gchar *profile,
